<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/medias.git

return [

	// M
	'medias_description' => 'Gestion des médias de SPIP',
	'medias_slogan' => 'Gestion des médias dans SPIP',
];
